#!/usr/bin/env bash
## Autogenerated template by neugs_utils

apt-get install -y clang
apt-get install -y gcc

apt-get install -y python3 python3-pip python3-dev

pip3 install -r /autograder/source/requirements.txt
